==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/dialog/dialog.m <==
extern const char **_dictionary_dialog;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_dialog;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_dialog("dialog",_dictionary_dialog,55,3);\
	void dummy_dict_dialog(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_dialog[id]
	#define MSG_B(id,m,n)	_dictionary_dialog[id]
	#define MSG_R(id)	_dictionary_dialog[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_dialog,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_dialog,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_dialog,id)
#endif
#define B_YES	0
#define B_NO	1
#define B_OK	2
#define B_ACCEPT	3
#define B_CANCEL	4
#define B_QUIT	5
#define B_SAVE	6
#define B_ADD	7
#define B_DEL	8
#define B_INS	9
#define B_EDIT	10
#define B_RESET	11
#define B_HELP	12
#define E_MISMATCH	13
#define B_MORE	14
#define B_USR1	15
#define B_USR2	16
#define B_USR3	17
#define E_INLIST	18
#define E_NOEMPTY	19
#define E_NOHELPFILE	20
#define E_NOPT	21
#define E_NONDIGIT	22
#define E_NOTTY	23
#define E_IVLDHTMLREQ	24
#define L_FREQUEST	25
#define L_REQUEST	26
#define F_PREFIX	27
#define T_PREFIX	28
#define I_PREFIX	29
#define T_HELPLIST	30
#define I_HELPLIST	31
#define X_YES	32
#define X_NO	33
#define X_ACCEPT	34
#define X_CANCEL	35
#define X_QUIT	36
#define X_SAVE	37
#define X_ADD	38
#define X_DEL	39
#define X_INS	40
#define X_EDIT	41
#define X_RESET	42
#define X_MORE	43
#define X_OKEY	44
#define E_GUIVER	45
#define E_NOEMPTYNAME	46
#define B_USR4	47
#define B_USR5	48
#define B_USR6	49
#define B_USR7	50
#define X_HELP	51
#define T_PICKHELP	52
#define H_HELPFILES	53
#define T_MAINHELP	54

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/dialog/dialog.m <==
extern const char **_dictionary_dialog;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_dialog;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_dialog("dialog",_dictionary_dialog,66,3);\
	void dummy_dict_dialog(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_dialog[id]
	#define MSG_B(id,m,n)	_dictionary_dialog[id]
	#define MSG_R(id)	_dictionary_dialog[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_dialog,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_dialog,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_dialog,id)
#endif
#define B_YES	0
#define B_NO	1
#define B_OK	2
#define B_ACCEPT	3
#define B_CANCEL	4
#define B_QUIT	5
#define B_SAVE	6
#define B_ADD	7
#define B_DEL	8
#define B_INS	9
#define B_EDIT	10
#define B_RESET	11
#define B_HELP	12
#define E_MISMATCH	13
#define B_MORE	14
#define B_USR1	15
#define B_USR2	16
#define B_USR3	17
#define E_INLIST	18
#define E_NOEMPTY	19
#define E_NOHELPFILE	20
#define E_NOPT	21
#define E_NONDIGIT	22
#define E_NOTTY	23
#define E_IVLDHTMLREQ	24
#define L_FREQUEST	25
#define L_REQUEST	26
#define F_PREFIX	27
#define T_PREFIX	28
#define I_PREFIX	29
#define T_HELPLIST	30
#define I_HELPLIST	31
#define X_YES	32
#define X_NO	33
#define X_ACCEPT	34
#define X_CANCEL	35
#define X_QUIT	36
#define X_SAVE	37
#define X_ADD	38
#define X_DEL	39
#define X_INS	40
#define X_EDIT	41
#define X_RESET	42
#define X_MORE	43
#define X_OKEY	44
#define E_GUIVER	45
#define E_NOEMPTYNAME	46
#define B_USR4	47
#define B_USR5	48
#define B_USR6	49
#define B_USR7	50
#define X_HELP	51
#define T_PICKHELP	52
#define H_HELPFILES	53
#define T_MAINHELP	54
#define E_MANYPT	55
#define F_DIALOG	56
#define F_FIELDSTATE	57
#define F_SAMPLEFIELD1	58
#define F_SAMPLEFIELD2	59
#define I_ICON	60
#define E_INVDATA	61
#define B_DISMISS	62
#define X_DISMISS	63
#define E_TOOMANYTHREADS	64
#define E_IVLDIPNUM	65
